from . import multioutput
from .inducing_patch import InducingPatches
from .inducing_variables import InducingPoints, InducingVariables, Multiscale
from .multioutput import (
    FallbackSeparateIndependentInducingVariables,
    FallbackSharedIndependentInducingVariables,
    MultioutputInducingVariables,
    SeparateIndependentInducingVariables,
    SharedIndependentInducingVariables,
)
